/* read-rtl-function.h - Reader for RTL function dumps
   Copyright (C) 2016-2021 Free Software Foundation, Inc.

This file is part of GCC.

GCC is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 3, or (at your option) any later
version.

GCC is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with GCC; see the file COPYING3.  If not see
<http://www.gnu.org/licenses/>.  */

#ifndef GCC_READ_RTL_FUNCTION_H
#define GCC_READ_RTL_FUNCTION_H

extern bool read_rtl_function_body (const char *path);

extern bool read_rtl_function_body_from_file_range (location_t start_loc,
						    location_t end_loc);

#endif /* GCC_READ_RTL_FUNCTION_H */
